@@ -20,17 +20,19 @@ class Table(object):
         "Init from a Series/Dataframe (df) of a file (name)"
         if df is not None:
             self.df = df
+            self.name = self.df.name
         elif name in self.names:
             self.name = name
             self.df = self.load(name)
             self.df.name = name
+        else:
+            print 'Wrong Table'
 
-
-    names = ['AME2003', 'AME2003all', 'AME2012', 'AME2012all', 'DUZU', 'FRDM95', 'KTUY05', 'ETFSI12', 'HFB14']
+    names = ['AME2003', 'AME2003all', 'AME2012', 'AME2012all', 'DUZU', 'FRDM95', 'KTUY05', 'ETFSI12', 'HFB14', 'TCSM12']
 
     def load(self, name):
         "Imports a mass table from a file"
-        filename = os.path.join(package_dir, 'data', name.upper() + '.txt')
+        filename = os.path.join(package_dir, 'data', name + '.txt')
         df = pd.read_csv(filename, header=0, delim_whitespace=True, index_col=[0, 1])
         return df['M']
 
